yakumo.cinder.v2.consistency_group.Manager

Package yakumo :: Package cinder :: Package v2 :: Module consistency_group :: Class Manager |
[hide private]
[frames] | no frames]

# Class Manager

source code

      object --+
               |
    base.Manager --+
                   |
                  Manager

manager class for consistency group on Block Storage V2 API

Nested Classes | [hide private]
| resource_class resource class for consistency group on Block Storage V2 API

Instance Methods | [hide private]
yakumo.cinder.v2.consistency_group.Resource |
create(self, name=`'``__UNDEF__``'`, description=`'``__UNDEF__``'`, volume_types=`'``__UNDEF__``'`, availability_zone=False) Create a consistency group | source code
yakumo.cinder.v2.consistency_group.Resource |
copy(self, name=None, description=None, source_cg=None, source_cg_snapshot=None, project=None, user=None) Create a consistency group from source | source code
Inherited from `base.Manager`: `__init__`, `find`, `find_one`, `get`, `get_empty`, `list` Inherited from `base.Manager` (private): `_attr2json`, `_find_gen`, `_json2attr`, `_no_such_api` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Class Variables | [hide private]
| service_type = ``'``volume``'``
| _attr_mapping = ``[``(``'``id``'``,` `'``id``'``,` <yakumo.mapper.NoopClass object `...``
| _json_resource_key = ``'``consistencygroup``'``
| _json_resources_key = ``'``consistencygroups``'``
| _url_resource_list_path = ``'``/consistencygroups/detail``'``
| _url_resource_path = ``'``/consistencygroups``'``
Inherited from `base.Manager` (private): `_has_detail`, `_has_extra_attr`, `_hidden_methods`, `_id_attr`, `_update_method`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### create(self, name=`'``__UNDEF__``'`, description=`'``__UNDEF__``'`, volume_types=`'``__UNDEF__``'`, availability_zone=False) | source code
Create a consistency group Parameters: `name` (str) - Consistency group name `description` (str) - Description `volume_types` ([yakumo.cinder.v2.volume_type.Resource]) - List of volume types `availability_zone` (yakumo.availability_zone.Resource) - Availability zone Returns: yakumo.cinder.v2.consistency_group.Resource Created volume object Overrides: base.Manager.create

### copy(self, name=None, description=None, source_cg=None, source_cg_snapshot=None, project=None, user=None) | source code
Create a consistency group from source Parameters: `name` (str) - Consistency group name `description` (str) - Description `source_cg` (yakumo.cinder.v2.consistency_group.Resource) - Source consistency group `source_cg_snapshot` (yakumo.cinder.v2.consistency_group_snapshot.Resource) - Source consistency group snapshot `project` - Project `project` - User Returns: yakumo.cinder.v2.consistency_group.Resource Copied volume object

Class Variable Details | [hide private]

  ### _attr_mapping Value:
      [('id', 'id', mapper.Noop), ('name', 'name', mapper.Noop), ('descripti
      on', 'display_description', mapper.Noop), ('volume_types', 'volume__ty
      pes', mapper.List(mapper.Resource('cinder.volume_type'))), ('availabil
      ity_zone', 'availability_zone', mapper.Resource('availability_zone')),
       ('status', 'status', mapper.Noop), ('created_at', 'created_at', mappe
      r.DateTime),]